<?php

/**
 * @file
 */

/**
 * Theme the response part of the response report
 *
 * @param array $data
 *   Array of groups. Each group is an array containing the following keys:
 *    - user_answers (optional) string A comma separated list of user answers.
 *    - correct_answers string A comma separated list of the correct answers
 *      for that group.
 *    - name string The name of the group.
 *    - feedback string Feedback on that group (Must be clean by this point).
 * @param boolean $display_user_answers
 *   TRUE to display the answers the user gave in the report.
 * @param string $general_feedback
 *   General feedback (Must be clean by this point).
 * @param boolean $showpoints
 *   TRUE to display the answer and score.
 * @param boolean $showfeedback
 *   TRUE to display the feedback.
 */
function theme_grouping_question_response($data, $display_user_answers = FALSE, $general_feedback = '', $showpoints = FALSE, $showfeedback = FALSE) {
  $rows = array();

  foreach ($data as $id => $group) {
    $user_answers_str = $group['user_answers'];
    $correct_answers_str = '';
    if ($showpoints) {
      $user_answers_str = '';
      $correct_answers = explode(',', $group['correct_answers']);

      if ($display_user_answers) {
        $user_answers = explode(',', $group['user_answers']);
        foreach ($user_answers as $answer) {
          $user_answers_str .= (in_array($answer, $correct_answers) ? $answer : '<strong class="error">' . $answer . '</strong>');
          $user_answers_str .= '<br />';
        }
      }

      foreach ($correct_answers as $correct_answer) {
        $correct_answers_str .= (!$display_user_answers || in_array($correct_answer, $user_answers) ? $correct_answer : '<strong class="error">' . $correct_answer . '</strong>');
        $correct_answers_str .= '<br />';
      }

    }

    $cols = array();

    $cols[] = array(
      'data' => "<span>{$id}. </span>",
      'width' => 35,
    );

    $cols[] = array(
      'data' => $group['name'],
    );

    if ($display_user_answers) {
      $cols[] = array(
        'data' => $user_answers_str,
      );
    }

    if ($showpoints) {
      $cols[] = array(
        'data' => $correct_answers_str,
      );
    }

    if ($showfeedback) {
      $cols[] = array(
        'data' => $group['feedback'],
      );
    }

    $rows[] = $cols;
  }

  $header = array();
  $header[] = array(
    'data' => '',
  );

  $header[] = array(
    'data' => t('Group'),
  );

  if ($display_user_answers) {
    $header[] = array(
      'data' => t('Your answers'),
    );
  }

  if ($showpoints) {
    $header[] = array(
      'data' => t('Correct Answer'),
    );
  }

  if ($showfeedback) {
    $header[] = array(
      'data' => t('Feedback'),
    );
  }

  $output = theme('table', $header, $rows);
  if ($showfeedback) {
    $output .= "<p>{$general_feedback}</p>";
  }

  return $output;
}

/**
 * Template preprocessor for the grouping question answer form
 */
function template_preprocess_grouping_question_answer_form_groups(&$vars) {
  $path = drupal_get_path('module', 'grouping_question');
  jquery_ui_add(array('ui.core', 'ui.draggable', 'ui.droppable'));
  drupal_add_js($path . '/js/grouping_question.js', 'module');
  drupal_add_css($path . '/theme/grouping_question.css', 'module', 'all');

  $vars['members'] = $vars['form']['members']['#value'];
  $vars['answers'] = '';
  $vars['answer_titles'] = array();

  foreach ($vars['form'] as $id => $group) {
    if (is_numeric($id) && intval($id) > 0) {
      $vars['answer_titles'][$id] = $group['user_answers']['#title'];
      $vars['answers'] .= drupal_render($group['user_answers']);
    }
  }
}

/**
 * Template preprocess function to render the creation form for
 * grouping questions
 */
function template_preprocess_grouping_question_creation(&$vars) {
  $rows = array();
  foreach ($vars['form'] as $id => $group) {
    if (is_numeric($id) && intval($id) > 0) {
      $row = array();
      $row[] = array('data' => drupal_render($group['name']));
      $row[] = array('data' => drupal_render($group['members']));
      $row[] = array('data' => '<div class="contain-ckeditor">' . drupal_render($group['feedback']) . '</div>');
      $rows[] = $row;
    }
  }

  $vars['output'] = '';

  if (!empty($rows)) {
    $header[] = array('data' => t('Group name'));
    $header[] = array('data' => t('Items'));
    $header[] = array('data' => t('Feedback'));
    $vars['output'] = theme('table', $header, $rows, array(), NULL, TRUE);
  }
}
